(define-module (zilti packages python)
  #:use-module (guix packages)
  #:use-module (guix download)
  #:use-module (guix git-download)
  #:use-module (guix build-system copy)
  #:use-module (guix build-system gnu)
  #:use-module (guix build-system pyproject)
  #:use-module (guix build-system python)
  #:use-module (guix gexp)
  #:use-module (guix utils)
  #:use-module (gnu packages)
  #:use-module (gnu packages admin)
  #:use-module (gnu packages base)
  #:use-module (gnu packages bash)
  #:use-module (gnu packages check)
  #:use-module (gnu packages cmake)
  #:use-module (gnu packages compression)
  #:use-module (gnu packages curl)
  #:use-module (gnu packages databases)
  #:use-module (gnu packages django)
  #:use-module (gnu packages freedesktop)
  #:use-module (gnu packages glib)
  #:use-module (gnu packages gnupg)
  #:use-module (gnu packages graphviz)
  #:use-module (gnu packages groff)
  #:use-module (gnu packages libevent)
  #:use-module (gnu packages libffi)
  #:use-module (gnu packages linux)
  #:use-module (gnu packages node)
  #:use-module (gnu packages openstack)
  #:use-module (gnu packages pcre)
  #:use-module (gnu packages protobuf)
  #:use-module (gnu packages pkg-config)
  #:use-module (gnu packages python)
  #:use-module (gnu packages python-build)
  #:use-module (gnu packages python-check)
  #:use-module (gnu packages python-compression)
  #:use-module (gnu packages python-crypto)
  #:use-module (gnu packages python-science)
  #:use-module (gnu packages python-web)
  #:use-module (gnu packages python-xyz)
  #:use-module (gnu packages qt)
  #:use-module (gnu packages rdf)
  #:use-module (gnu packages rpc)
  #:use-module (gnu packages serialization)
  #:use-module (gnu packages sphinx)
  #:use-module (gnu packages texinfo)
  #:use-module (gnu packages tls)
  #:use-module (gnu packages time)
  #:use-module (gnu packages version-control)
  #:use-module (gnu packages web)
  #:use-module (gnu packages xml)
  #:use-module ((guix licenses) #:prefix license:)
  #:use-module (srfi srfi-1))


(define-public python-wheel
  (package
    (name "python-wheel")
    (version "0.43.0")
    (source
      (origin
        (method url-fetch)
        (uri (pypi-uri "wheel" version))
        (sha256
         (base32
          "118x5y37152by7f8gvzwda441jd8b42w92ngs6i5sp7sd4ngjpj6"))))
    (build-system pyproject-build-system)
    (native-inputs
     (list python-flit-core))
    (home-page "https://github.com/pypa/wheel")
    (synopsis "Format for built Python packages")
    (description
     "A wheel is a ZIP-format archive with a specially formatted filename and
the @code{.whl} extension.  It is designed to contain all the files for a PEP
376 compatible install in a way that is very close to the on-disk format.  Many
packages will be properly installed with only the @code{Unpack} step and the
unpacked archive preserves enough information to @code{Spread} (copy data and
scripts to their final locations) at any later time.  Wheel files can be
installed with a newer @code{pip} or with wheel's own command line utility.")
    (license license:expat)))

(define-public python-pypa-build-1
  (package
    (name "python-pypa-build")
    (version "1.1.1")
    (source (origin
              (method url-fetch)
              (uri (pypi-uri "build" version))
              (sha256
               (base32
                "0c9a7nalcyryxp85nf8sj2bpvnd6sgdchb5s6kkw5ami8nxnbslf"))))
    (build-system pyproject-build-system)
    (arguments
     `(#:tests? #f))                    ;to tests in the PyPI release
    (native-inputs
     (list python-flit-core))
    (propagated-inputs
     `(("python-pyproject-hooks" ,python-pyproject-hooks)
       ("python-packaging" ,python-packaging-bootstrap)))
    (home-page "https://pypa-build.readthedocs.io/en/latest/")
    (synopsis "Simple Python PEP 517 package builder")
    (description "The @command{build} command invokes the PEP 517 hooks to
build a distribution package.  It is a simple build tool and does not perform
any dependency management.  It aims to keep dependencies to a minimum, in
order to make bootstrapping easier.")
    (license license:expat)))

(define-public python-botocore
  ;; Note: When updating botocore, also make sure that boto3 and awscli
  ;; are compatible.
  (package
    (name "python-botocore")
    (version "1.34.61")
    (source
     (origin
       (method url-fetch)
       (uri (pypi-uri "botocore" version))
       (sha256
        (base32
         "0d3h7phvlbri3dqjkn6q9jzgg6xywis8rm42r192afg6wkvlmpvj"))))
    (build-system pyproject-build-system)
    (arguments
     ;; FIXME: Many tests are failing.
     '(#:tests? #f))
    (propagated-inputs
     (list python-dateutil python-jmespath python-urllib3))
    (home-page "https://github.com/boto/botocore")
    (synopsis "Low-level interface to AWS")
    (description "Botocore is a Python library that provides a low-level
interface to the Amazon Web Services (AWS) API.")
    (license license:asl2.0)))

(define-public python-boto3
  (package
    (name "python-boto3")
    (version "1.34.61")
    (home-page "https://github.com/boto/boto3")
    (source (origin
              (method git-fetch)
              (uri (git-reference (url home-page) (commit version)))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1nbq2rly56gia2z2zh57qwpafsj2w3258gz4k6z494bws0fb99nb"))))
    (arguments
     `(#:phases
       (modify-phases %standard-phases
         (add-after 'unpack 'delete-network-tests
           ;; Deleting integration tests because they are trying to connect to AWS.
           (lambda _
             (delete-file-recursively "tests/integration")))
         (replace 'check
           (lambda* (#:key tests? #:allow-other-keys)
             (when tests?
               (invoke "pytest" "-v")))))))
    (build-system pyproject-build-system)
    (native-inputs
     (list python-nose python-mock python-pytest))
    (propagated-inputs
     (list python-botocore python-jmespath python-s3transfer))
    (synopsis "AWS SDK for Python")
    (description
     "Boto3 is a Python library for writing programs that interact with
@acronym{AWS,Amazon Web Services}.")
    (license license:asl2.0)))

(define-public python-s3transfer
  (package
    (name "python-s3transfer")
    (version "0.10.0")
    (source (origin
              (method url-fetch)
              (uri (pypi-uri "s3transfer" version))
              (sha256
               (base32
                "0nsr664ci9bqysmiqrigv03kz5idjwxy4ibrwpjbpvnmfbvbpj6h"))))
    (build-system pyproject-build-system)
    (arguments
     `(#:phases
       (modify-phases %standard-phases
         (delete 'check))))
    (native-inputs
     (list python-docutils python-mock python-nose))
    (propagated-inputs
     (list python-botocore python-urllib3))
    (synopsis "Amazon S3 Transfer Manager")
    (description "S3transfer is a Python library for managing Amazon S3
transfers.")
    (home-page "https://github.com/boto/s3transfer")
    (license license:asl2.0)))

(define-public awscli
  (package
    ;; Note: updating awscli typically requires updating botocore as well.
    (name "awscli")
    (version "1.32.61")
    (source
     (origin
       (method url-fetch)
       (uri (pypi-uri name version))
       (sha256
        (base32
         "1xms4yd07i8869jk7kmd0p80fj7qnf18kip3kmxwalnqygpwsqfw"))))
    (build-system pyproject-build-system)
    (arguments
     ;; FIXME: The 'pypi' release does not contain tests.
     '(#:tests? #f
       #:phases
       (modify-phases %standard-phases
         (add-after 'unpack 'use-recent-pyyaml
           (lambda _
             (substitute* '("awscli.egg-info/requires.txt"
                            "setup.cfg"
                            "setup.py")
               (("<5.5") "<=6"))))
         (add-after 'unpack 'fix-reference-to-groff
           (lambda* (#:key inputs #:allow-other-keys)
             (substitute* "awscli/help.py"
               (("if not self._exists_on_path\\('groff'\\):") "")
               (("raise ExecutableNotFoundError\\('groff'\\)") "")
               (("cmdline = \\['groff'")
                (string-append "cmdline = ['"
                               (search-input-file inputs "bin/groff")
                               "'"))))))))
    (inputs
     (list groff
           python-colorama-for-awscli
           python-botocore
           python-s3transfer
           python-docutils-0.15
           python-pyyaml
           python-rsa))
    (home-page "https://aws.amazon.com/cli/")
    (synopsis "Command line client for AWS")
    (description "AWS CLI provides a unified command line interface to the
Amazon Web Services (AWS) API.")
    (license license:asl2.0)))

(define-public python-ruamel-base
  (package
   (name "python-ruamel-base")
   (version "1.0.0")
   (source
    (origin
     (method url-fetch)
     (uri (pypi-uri "ruamel.base" version))
     (sha256
      (base32
       "1wswxrn4givsm917mfl39rafgadimf1sldpbjdjws00g1wx36hf0"))))
   (build-system pyproject-build-system)
   (arguments
    (list #:tests? #f))
   (home-page "https://aws.amazon.com/cli/")
   (synopsis "Command line client for AWS")
   (description "AWS CLI provides a unified command line interface to the
Amazon Web Services (AWS) API.")
   (license license:asl2.0)))

(define-public python-ruamel-yaml-clib
  (package
   (name "python-ruamel-yaml-clib")
   (version "0.2.7")
   (source
    (origin
     (method url-fetch)
     (uri (pypi-uri "ruamel.yaml.clib" version))
     (sha256
      (base32
       "15wlbw7wys3nana0xgip8mgjlpcr1f2qwrvivf04377a5ddgs20z"))))
   (build-system pyproject-build-system)
   (arguments
    (list #:tests? #f))
   (inputs
    (list python-ruamel-base
          python-ruamel-yaml))
   (home-page "https://aws.amazon.com/cli/")
   (synopsis "Command line client for AWS")
   (description "AWS CLI provides a unified command line interface to the
Amazon Web Services (AWS) API.")
   (license license:asl2.0)))

(define-public python-ruamel-yaml
  (package
    (name "python-ruamel-yaml")
    (version "0.17.32")
    (source
     (origin
       (method url-fetch)
       (uri (pypi-uri "ruamel.yaml" version))
       (sha256
        (base32
         "1hpg033cyw7h3kv44qxbb443phikdnx5qalp892y250rfrir14zc"))))
    (build-system pyproject-build-system)
    (arguments
     (list #:tests? #f
           #:phases
           #~(modify-phases %standard-phases
               (delete 'sanity-check))))
    (inputs
     (list python-ruamel-base))
    (home-page "https://aws.amazon.com/cli/")
    (synopsis "Command line client for AWS")
    (description "AWS CLI provides a unified command line interface to the
Amazon Web Services (AWS) API.")
    (license license:asl2.0)))

(define-public python-awscrt
  (package
    (name "python-awscrt")
    (version "0.20.5")
    (source
     (origin
       (method url-fetch)
       (uri (pypi-uri "awscrt" version))
       (sha256
        (base32
         "1li94chzfaqam3vkwaw33j2c861g5lg9vkybnnx72crq6m5yk75z"))))
    (build-system pyproject-build-system)
    (arguments
     (list #:tests? #f))
    (inputs
     (list cmake))
    (home-page "https://aws.amazon.com/cli/")
    (synopsis "Command line client for AWS")
    (description "AWS CLI provides a unified command line interface to the
Amazon Web Services (AWS) API.")
    (license license:asl2.0)))

